from .model import Model

class DeliveryReport(Model):

    def _accepted_params(self):
        return [
              'correlationId',
              'sessionId',
              'transactionId',
              'price',
              'sender',
              'recipient',
              'operatorId',
              'statusCode',
              'detailedStatusCode',
              'statusDescription',
              'delivered',
              'billed',
              'smscTransactionId',
              'smscMessageParts',
              'smscStatus',
              'received',
              'properties',
        ]



from .model import Model

class KeywordPreAuthSettings(Model):


    def _accepted_params(self):
        return [
            'InfoText',
            'InfoSender',
            'PrefixMessage',
            'PostfixMessage',
            'Delay',
            'MerchantId',
            'ServiceDescription',
            'Active',
        ]



from .model import Model

class Pincode(Model):

    def _accepted_params(self):
        return [
            'transactionId',
            'recipient',
            'sender',
            'prefixText',
            'suffixText',
            'pincodeLength',
            'maxAttempts',
        ]
